@@ -4,7 +4,6 @@ from django.contrib.auth.models import User
 from django.db import models
 from django.utils.translation import ugettext as _
 
-from linaro_django_xmlrpc.models import AuthToken
 
 class JSONDataError(ValueError):
     """Error raised when JSON is syntactically valid but ill-formed."""
@@ -136,8 +135,6 @@ class TestJob(models.Model):
         verbose_name = _(u"Submitter"),
     )
 
-    submit_token = models.ForeignKey(AuthToken, null=True)
-
     description = models.CharField(
         verbose_name = _(u"Description"),
         max_length = 200,
