@@ -9,8 +9,6 @@ from django.test.client import Client
 
 from django_testscenarios.ubertest import TestCase
 
-from linaro_django_xmlrpc.models import AuthToken
-
 from lava_scheduler_app.models import Device, DeviceType, Tag, TestJob
 
 
@@ -415,86 +413,12 @@ class TestDBJobSource(TransactionTestCaseWithFactory):
         device = Device.objects.get(pk=device.pk)
         self.assertEqual(job, device.current_job)
 
-    def test_getJobForBoard_creates_token(self):
-        device = self.factory.make_device(hostname='panda01')
-        job = self.factory.make_testjob(requested_device=device)
-        transaction.commit()
-        DatabaseJobSource().getJobForBoard_impl('panda01')
-        # reload from the database
-        job = TestJob.objects.get(pk=job.pk)
-        device = Device.objects.get(pk=device.pk)
-        self.assertIsNotNone(job.submit_token)
-        self.assertEqual(job.submitter, job.submit_token.user)
-
-    def test_getJobForBoard_inserts_target_into_json(self):
-        panda_type = self.factory.ensure_device_type(name='panda')
-        self.factory.make_device(hostname='panda01', device_type=panda_type)
-        definition = {'foo': 'bar'}
-        self.factory.make_testjob(
-            requested_device_type=panda_type,
-            definition=json.dumps(definition))
-        transaction.commit()
-        json_data = DatabaseJobSource().getJobForBoard_impl('panda01')
-        self.assertIn('target', json_data)
-        self.assertEqual('panda01', json_data['target'])
-
-    def test_getJobForBoard_inserts_submit_token_into_json(self):
-        panda_type = self.factory.ensure_device_type(name='panda')
-        self.factory.make_device(hostname='panda01', device_type=panda_type)
-        definition = {
-            'actions': [
-                {
-                    "command": "submit_results",
-                    "parameters":
-                    {
-                        "server": "http://test-server/RPC2/",
-                        "stream": "/private/personal/test/test/",
-                    }
-                }
-            ]
-        }
-        job = self.factory.make_testjob(
-            requested_device_type=panda_type,
-            definition=json.dumps(definition))
-        transaction.commit()
-        json_data = DatabaseJobSource().getJobForBoard_impl('panda01')
-        job = TestJob.objects.get(pk=job.pk)
-        submit_job_params = json_data['actions'][0]['parameters']
-        self.assertIn('token', submit_job_params)
-        self.assertEqual(job.submit_token.secret, submit_job_params['token'])
-
-    def test_getJobForBoard_adds_user_to_url(self):
-        panda_type = self.factory.ensure_device_type(name='panda')
-        self.factory.make_device(hostname='panda01', device_type=panda_type)
-        user = User.objects.create_user('test', 'e@mail.invalid', 'test')
-        user.save()
-        definition = {
-            'actions': [
-                {
-                    "command": "submit_results",
-                    "parameters":
-                    {
-                        "server": "http://test-server/RPC2/",
-                        "stream": "/private/personal/test/test/",
-                    }
-                }
-            ]
-        }
-        job = self.factory.make_testjob(
-            requested_device_type=panda_type, submitter=user,
-            definition=json.dumps(definition))
-        transaction.commit()
-        json_data = DatabaseJobSource().getJobForBoard_impl('panda01')
-        job = TestJob.objects.get(pk=job.pk)
-        submit_job_params = json_data['actions'][0]['parameters']
-        self.assertEqual("http://test@test-server/RPC2/", submit_job_params['server'])
-
     def get_device_and_running_job(self):
         device = self.factory.make_device(hostname='panda01')
         job = self.factory.make_testjob(requested_device=device)
         transaction.commit()
         DatabaseJobSource().getJobForBoard_impl('panda01')
-        return device, TestJob.objects.get(pk=job.pk)
+        return device, job
 
     def test_jobCompleted_set_statuses_success(self):
         device, job = self.get_device_and_running_job()
@@ -545,15 +469,6 @@ class TestDBJobSource(TransactionTestCaseWithFactory):
         device = Device.objects.get(pk=device.pk)
         self.assertEquals(None, device.current_job)
 
-    def test_jobCompleted_deletes_token(self):
-        device, job = self.get_device_and_running_job()
-        token = job.submit_token
-        transaction.commit()
-        DatabaseJobSource().jobCompleted_impl('panda01', 0)
-        self.assertRaises(
-            AuthToken.DoesNotExist,
-            AuthToken.objects.get, pk=token.pk)
-
     def test_getLogFileForJobOnBoard_returns_writable_file(self):
         device, job = self.get_device_and_running_job()
         definition = {'foo': 'bar'}
