@@ -1,7 +1,6 @@
 import datetime
 import json
 import logging
-import urlparse
 
 from django.core.files.base import ContentFile
 from django.db import connection
@@ -9,8 +8,6 @@ from django.db import IntegrityError, transaction
 from django.db.models import Q
 from django.db.utils import DatabaseError
 
-from linaro_django_xmlrpc.models import AuthToken
-
 from twisted.internet.threads import deferToThread
 
 from zope.interface import implements
@@ -18,7 +15,6 @@ from zope.interface import implements
 from lava_scheduler_app.models import Device, TestJob
 from lava_scheduler_daemon.jobsource import IJobSource
 
-
 try:
     from psycopg2 import InterfaceError, OperationalError
 except ImportError:
@@ -81,35 +77,6 @@ class DatabaseJobSource(object):
     def getBoardList(self):
         return self.deferForDB(self.getBoardList_impl)
 
-    def _get_json_data(self, job):
-        json_data = json.loads(job.definition)
-        json_data['target'] = job.actual_device.hostname
-        # The rather extreme paranoia in what follows could be much reduced if
-        # we thoroughly validated job data in submit_job.  We don't (yet?)
-        # and there is no sane way to report errors at this stage, so,
-        # paranoia (the dispatcher will choke on bogus input in a more
-        # informative way).
-        if 'actions' not in json_data:
-            return json_data
-        actions = json_data['actions']
-        for action in actions:
-            if not isinstance(action, dict):
-                continue
-            if action.get('command') != 'submit_results':
-                continue
-            params = action.get('parameters')
-            if not isinstance(params, dict):
-                continue
-            params['token'] = job.submit_token.secret
-            if not 'server' in params or not isinstance(params['server'], unicode):
-                continue
-            parsed = urlparse.urlsplit(params['server'])
-            netloc = job.submitter.username + '@' + parsed.hostname
-            parsed = list(parsed)
-            parsed[1] = netloc
-            params['server'] = urlparse.urlunsplit(parsed)
-        return json_data
-
     def getJobForBoard_impl(self, board_name):
         while True:
             device = Device.objects.get(hostname=board_name)
@@ -158,9 +125,9 @@ class DatabaseJobSource(object):
                 else:
                     job.log_file.save(
                         'job-%s.log' % job.id, ContentFile(''), save=False)
-                    job.submit_token = AuthToken.objects.create(user=job.submitter)
                     job.save()
-                    json_data = self._get_json_data(job)
+                    json_data = json.loads(job.definition)
+                    json_data['target'] = device.hostname
                     transaction.commit()
                     return json_data
             else:
@@ -205,7 +172,6 @@ class DatabaseJobSource(object):
                 "Unexpected job state in jobCompleted: %s" % job.status)
             job.status = TestJob.COMPLETE
         job.end_time = datetime.datetime.utcnow()
-        job.submit_token.delete()
         device.save()
         job.save()
 
